pub struct OutputTooShortError {
pub required: usize,
pub available: usize,
}Expand description
Reports that an output buffer cannot contain a prepared layout.
Fields
required: usizeThe exact number of bytes required by the prepared layout.
available: usizeThe number of bytes available in the supplied output buffer.