pub struct PrefixExtent { /* private fields */ }Expand description
The nonzero extent occupied by a validated encoded prefix.
Implementations
Sourceimpl PrefixExtent
impl PrefixExtent
Sourcepub const fn new(encoded_len: NonZeroUsize) -> Self
pub const fn new(encoded_len: NonZeroUsize) -> Self
Creates an extent from a nonzero encoded length.
Sourcepub const fn encoded_len(self) -> NonZeroUsize
pub const fn encoded_len(self) -> NonZeroUsize
Returns the number of bytes occupied by the encoded prefix.