Module codec

Module codec 

Codec contracts and built-in codecs. Codec contracts and built-in integer codecs.

Structs

BeI16
Big-endian i16 codec.
BeI32
Big-endian i32 codec.
BeI64
Big-endian i64 codec.
BeI128
Big-endian i128 codec.
BeU16
Big-endian u16 codec.
BeU24
Big-endian unsigned 24-bit integer codec over u32.
BeU32
Big-endian u32 codec.
BeU64
Big-endian u64 codec.
BeU128
Big-endian u128 codec.
Bytes
A borrowed fixed-width span of wire bytes with no content interpretation.
ExactWidthError
Error returned when an exact-width byte value has the wrong length.
I8
One-byte signed integer codec.
LeI16
Little-endian i16 codec.
LeI32
Little-endian i32 codec.
LeI64
Little-endian i64 codec.
LeI128
Little-endian i128 codec.
LeU16
Little-endian u16 codec.
LeU24
Little-endian unsigned 24-bit integer codec over u32.
LeU32
Little-endian u32 codec.
LeU64
Little-endian u64 codec.
LeU128
Little-endian u128 codec.
PrefixExtent
The nonzero extent occupied by a validated encoded prefix.
U8
One-byte unsigned integer codec.
U24RangeError
Error returned when a u32 does not fit in an unsigned 24-bit integer.

Traits

EncodePlan
A completed, infallible encoding operation.
FixedCodec
A codec whose encoded representation always has one fixed width.
PrefixCodec
A codec whose encoded representation occupies a variable-length prefix.