Codec contracts and built-in codecs. Codec contracts and built-in integer codecs.
Structs
- BeI16
- Big-endian
i16codec. - BeI32
- Big-endian
i32codec. - BeI64
- Big-endian
i64codec. - BeI128
- Big-endian
i128codec. - BeU16
- Big-endian
u16codec. - BeU24
- Big-endian unsigned 24-bit integer codec over
u32. - BeU32
- Big-endian
u32codec. - BeU64
- Big-endian
u64codec. - BeU128
- Big-endian
u128codec. - Bytes
- A borrowed fixed-width span of wire bytes with no content interpretation.
- Exact
Width Error - Error returned when an exact-width byte value has the wrong length.
- I8
- One-byte signed integer codec.
- LeI16
- Little-endian
i16codec. - LeI32
- Little-endian
i32codec. - LeI64
- Little-endian
i64codec. - LeI128
- Little-endian
i128codec. - LeU16
- Little-endian
u16codec. - LeU24
- Little-endian unsigned 24-bit integer codec over
u32. - LeU32
- Little-endian
u32codec. - LeU64
- Little-endian
u64codec. - LeU128
- Little-endian
u128codec. - Prefix
Extent - The nonzero extent occupied by a validated encoded prefix.
- U8
- One-byte unsigned integer codec.
- U24Range
Error - Error returned when a
u32does not fit in an unsigned 24-bit integer.
Traits
- Encode
Plan - A completed, infallible encoding operation.
- Fixed
Codec - A codec whose encoded representation always has one fixed width.
- Prefix
Codec - A codec whose encoded representation occupies a variable-length prefix.